import Qt 4.7

/* Grid view displaying applications surrounded by a frame that clips it.

   Clicking on an application launches it.

   The 'model' property holds the list of applications that ought to be a list
   of paths to .desktop files.
   The 'delegate' property holds the delegate for the grid view.
*/
FocusScope {
    property alias model: grid.model
    property alias delegate: grid.delegate
    property QLauncherApplication launching_application

    ApplicationLaunchFeedback {
        anchors.centerIn: parent
        application: launching_application ? launching_application : null
        opacity: launching_application ? 1 : 0

        onCancelled: launching_application = null

        Behavior on opacity {NumberAnimation {duration: 200; easing.type: Easing.InOutQuad}}
    }

    GridView {
        id: grid

        property int min_horizontal_spacing: 20
        property int min_vertical_spacing: 15
        property int delegate_width: 176
        property int delegate_height: 172

        /* Compute the number of cells per line and column so that:
            - the items are always centered horizontally within the grid (= same
              margins on the right and left sides of the grid)
            - the spacing between items is kept as small as possible but always
              greater than min_horizontal_spacing and min_vertical_spacing
            - a non integer number of lines is shown as to indicate the
              availability of more lines to the user and incitate scrolling
        */
        property real cells_per_line: Math.floor(width/(min_horizontal_spacing+delegate_width))
        property real cells_per_column: Math.floor(height/(min_vertical_spacing+delegate_height))+0.4
        property int horizontal_spacing: Math.floor(width/cells_per_line-delegate_width)
        property int vertical_spacing: Math.floor(height/cells_per_column-delegate_height)

        anchors.rightMargin: 40
        anchors.leftMargin: 40
        anchors.bottomMargin: 8
        anchors.topMargin: 8
        anchors.fill: parent

        cellWidth: delegate_width+horizontal_spacing
        cellHeight: delegate_height+vertical_spacing
        flow: GridView.LeftToRight
        highlightRangeMode: GridView.StrictlyEnforceRange
        preferredHighlightBegin: 35
        preferredHighlightEnd: 35
        currentIndex: 0

        clip: true
        focus: true
        opacity: launching_application ? 0 : 1
        Behavior on opacity {NumberAnimation {duration: 200; easing.type: Easing.InOutQuad}}
    }
}
