import Qt 4.7
import QtMobility.publishsubscribe 1.0

/* Main entry point of the launcher.

   It contains a background image and a tabulated element holding:
    - the connections page
    - the system settings page

    Switching between pages is done through a GConf key storing the index of
    the page that is to be shown:

     /apps/hedley_launcher/current_page
*/
Item {
    /* Minimal size */
    width: 1024
    height: 768

    Image {
        id: background

        /* Activating antialiasing would increase CPU usage */
        smooth: false
        fillMode: Image.PreserveAspectCrop
        anchors.fill: parent
        source: gconf_background_path.value ? gconf_background_path.value : "/usr/share/backgrounds/hedley.png"
    }

    Item {
        /* The launcher is a desktop window (fullscreen with no decorations).
           We need to account for the top panel overlapping on the window.
         */
        anchors.fill: parent
        anchors.topMargin: 43 /* height of the top panel */

        ValueSpaceSubscriber {
            id: gconf_background_path
            path: "/apps/hedley_launcher/background_path"
        }

        ValueSpaceSubscriber {
            id: gconf_current_page
            path: "/apps/hedley_launcher/current_page"
        }

        BorderImage {
            id: frame

            anchors.fill: parent
            anchors.topMargin: 25
            anchors.bottomMargin: 40
            anchors.leftMargin: 40
            anchors.rightMargin: 40

            border.bottom: 9
            border.top: 9
            border.right: 9
            border.left: 9
            /* Warning: not setting the tile mode to 'repeat' incurs a performance
                        cost */
            horizontalTileMode: BorderImage.Repeat
            verticalTileMode: BorderImage.Repeat
            smooth: false
            source: "artwork/applications_border.png"
        }

        Tab {
            id: pages

            anchors.fill: frame
            currentPage: gconf_current_page.value
            focus: true

            ConnectionsPage {
                id: connections_page

                property color color: "#28a8e0"
                active: true
                focus: true
                opacity: 1
                anchors.fill: parent
                Behavior on opacity {NumberAnimation {duration: 200; easing.type: Easing.InOutQuad}}
            }

            SystemSettingsPage {
                id: system_settings_page

                property color color: "#00aa21"
                opacity: 0
                anchors.fill: parent
                Behavior on opacity {NumberAnimation {duration: 200; easing.type: Easing.InOutQuad}}
            }

            Page {
                id: information_page

                property color color: "#faaf42"
                opacity: 0
                anchors.fill: parent
                Behavior on opacity {NumberAnimation {duration: 200; easing.type: Easing.InOutQuad}}
            }

            Page {
                id: power_page

                property color color: "#f16724"
                opacity: 0
                anchors.fill: parent
                Behavior on opacity {NumberAnimation {duration: 200; easing.type: Easing.InOutQuad}}
            }
        }

        /* Very thin color bar positioned at the top and indicating what page
           is currently on */
        Row {
            id: color_bar

            anchors.top: parent.top
            anchors.left: parent.left
            anchors.right: parent.right
            height: 2

            Rectangle {
                id: connections_page_bar

                width: 50
                height: parent.height
                color: connections_page.color
            }

            Rectangle {
                id: current_page_bar

                width: parent.width
                       - connections_page_bar.width
                       - system_settings_page_bar.width
                       - information_page_bar.width
                       - power_page_bar.width
                height: parent.height
                color: pages.children[pages.currentPage].color
            }

            Rectangle {
                id: system_settings_page_bar

                width: 42
                height: parent.height
                color: system_settings_page.color
            }

            Rectangle {
                id: information_page_bar

                width: 42
                height: parent.height
                color: information_page.color
            }

            Rectangle {
                id: power_page_bar

                width: 42
                height: parent.height
                color: power_page.color
            }
        }
    }
}
