#include "qfilesystemmodelqml.h"

QFileSystemModelQML::QFileSystemModelQML(QObject * parent) : QFileSystemModel(parent)
{
    /* For some unknown reason the VisualDataModel wrapping our model does not tell
       the view to refresh itself when rows are inserted, removed or moved.

       Yes, a VisualDataModel is implicitly created when setting a QAbstractItemModel
       and the rowsInserted, rowsRemoved, rowsMoved signals are set to be
       transformed into the itemsInserted, itemsRemoved, itemsMoved signals that the
       view uses to refresh itself.
       Looks like the culprits could be lines 1349 and 1355 of qdeclarativevisualitemmodel.cpp

       In order to workaround that we call QAbstractItemModel::reset that VisualDataModel
       forwards inconditionally thus refreshing the view.
    */
    QObject::connect(this, SIGNAL(rowsInserted(QModelIndex,int,int)),
                     this, SLOT(reset()));
    QObject::connect(this, SIGNAL(rowsRemoved(QModelIndex,int,int)),
                     this, SLOT(reset()));
    QObject::connect(this, SIGNAL(rowsMoved(QModelIndex,int,int,QModelIndex,int)),
                     this, SLOT(reset()));
    QObject::connect(this, SIGNAL(layoutChanged()),
                     this, SLOT(reset()));
}

void
QFileSystemModelQML::reset()
{
    QFileSystemModel::reset();
}

QModelIndex
QFileSystemModelQML::setRootPath(const QString & newPath)
{
    rootIndex = QFileSystemModel::setRootPath(newPath);
    return rootIndex;
}


/* Force the QModelIndex passed to be the 'rootIndex'; necessary because QML's views
   only work with lists (no QModelIndex), so one has to be chosen.
   There is a clean way to achieve that using a VisualDataModel wrapping
   the QFileSystemModelQML and setting its 'rootIndex' property.
   Unfortunately that approach triggered other issues.
*/
int
QFileSystemModelQML::rowCount(const QModelIndex & parent) const
{
    return QFileSystemModel::rowCount(QFileSystemModel::index(rootPath()));
}

QModelIndex
QFileSystemModelQML::index(int row, int column, const QModelIndex & parent) const
{
    return QFileSystemModel::index(row, column, QFileSystemModel::index(rootPath()));
}

bool
QFileSystemModelQML::hasChildren(const QModelIndex & parent) const
{
    return QFileSystemModel::hasChildren(QFileSystemModel::index(rootPath()));

}
