#include "qsortfilterproxymodelqml.h"

QSortFilterProxyModelQML::QSortFilterProxyModelQML(QObject *parent) :
    QSortFilterProxyModel(parent)
{
    /* For some unknown reason the VisualDataModel wrapping our model does not tell
       the view to refresh itself when rows are inserted, removed or moved.

       Yes, a VisualDataModel is implicitly created when setting a QAbstractItemModel
       and the rowsInserted, rowsRemoved, rowsMoved signals are set to be
       transformed into the itemsInserted, itemsRemoved, itemsMoved signals that the
       view uses to refresh itself.
       Looks like the culprits could be lines 1349 and 1355 of qdeclarativevisualitemmodel.cpp

       In order to workaround that we call QAbstractItemModel::reset that VisualDataModel
       forwards inconditionally thus refreshing the view.
    */
    QObject::connect(this, SIGNAL(rowsInserted(QModelIndex,int,int)),
                     this, SLOT(reset()));
    QObject::connect(this, SIGNAL(rowsRemoved(QModelIndex,int,int)),
                     this, SLOT(reset()));
    QObject::connect(this, SIGNAL(rowsMoved(QModelIndex,int,int,QModelIndex,int)),
                     this, SLOT(reset()));
    QObject::connect(this, SIGNAL(layoutChanged()),
                     this, SLOT(reset()));
}

void
QSortFilterProxyModelQML::reset()
{
    QSortFilterProxyModel::reset();
}


QObject*
QSortFilterProxyModelQML::sourceModelQObject() const
{
    return (QAbstractItemModel*)sourceModel();
}

void
QSortFilterProxyModelQML::setSourceModelQObject(QObject *model)
{
    setSourceModel((QAbstractItemModel*)model);
    sort(0);
}
